@@ -1,4 +1,4 @@
-/* $Id: bogotune.c,v 1.226 2005/09/04 14:49:43 relson Exp $ */
+/* $Id: bogotune.c,v 1.231 2006/05/29 14:28:00 relson Exp $ */
 
 /*****************************************************************************
 
@@ -8,6 +8,7 @@ NAME:
 AUTHORS:
    Greg Louis - perl version
    David Relson - C version
+   Matthias Andree - options parser usability
 
 ******************************************************************************/
 
@@ -48,7 +49,6 @@ AUTHORS:
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
 
 #include "bogotune.h"
 
@@ -891,7 +891,7 @@ static void print_version(void)
     (void)fprintf(stderr,
 		  "%s version %s\n"
 		  "    Database: %s\n"
-		  "Copyright (C) 2002-2005 Greg Louis, David Relson\n\n"
+		  "Copyright (C) 2002-2006 Greg Louis, David Relson\n\n"
 		  "%s comes with ABSOLUTELY NO WARRANTY.  "
 		  "This is free software, and\nyou are welcome to "
 		  "redistribute it under the General Public License.  "
@@ -936,6 +936,7 @@ static struct option longopts_bogotune[] = {
 static int process_arglist(int argc, char **argv)
 {
     int  count = 1;
+    int  lastmode = -1;
 
     bulk_mode = B_CMDLINE;
 
@@ -949,12 +950,28 @@ static int process_arglist(int argc, char **argv)
     while (1)
     {
 	int option;
-	
-	option = getopt(argc, argv, OPTIONS);
+
+	option = getopt(argc, argv, "-" OPTIONS);
+	/* the "-" is a GNU getopt special to enable RETURN_IN_ORDER
+	 * behavior, i. e. nonoption arguments are returned as
+	 * option == 1 here. */
 
 	if (option == -1)
  	    break;
 
+	if (option == 1) {
+	    /* If getopt's RETURN_IN_ORDER behavior */
+	    switch (lastmode) {
+	    case 'n':
+	    case 's':
+		option = lastmode;
+		break;
+	    default:
+		fprintf(stderr,
+			"File names may only be given after -n or -s options.\n");
+	    }
+	}
+
 	switch (option) {
 	case 'c':
 	    read_config_file(optarg, false, false, PR_CFG_USER, longopts_bogotune);
@@ -979,8 +996,8 @@ static int process_arglist(int argc, char **argv)
 	    bogolex_file = optarg;
 	    break;
 	case 'n':
-	    run_type = REG_GOOD;
-	    filelist_add( ham_files, optarg );
+	    lastmode = 'n';
+	    filelist_add(ham_files, optarg);
 	    break;
 	case 'q':
 	    quiet = true;
@@ -989,8 +1006,8 @@ static int process_arglist(int argc, char **argv)
 	    user_robx = atof(optarg);
 	    break;
 	case 's':
-	    run_type = REG_SPAM;
-	    filelist_add( spam_files, optarg );
+	    lastmode = 's';
+	    filelist_add(spam_files, optarg);
 	    break;
 #ifdef	TEST
 	case 't':
@@ -1495,8 +1512,10 @@ static rc_t bogotune(void)
     */
 
     robx = get_robx();
-    db_cachesize = calc_db_cachesize();
-    printf("Recommended db cache size is %u MB\n", db_cachesize);
+    if (ds_flag == DS_DSK) {
+	db_cachesize = calc_db_cachesize();
+	printf("Recommended db cache size is %u MB\n", db_cachesize);
+    }
 
     /*
     ** 6.  Calculate fp target
