@@ -1,4 +1,4 @@
-/* $Id: datastore_db_private.h,v 1.15 2005/04/04 11:48:49 relson Exp $ */
+/* $Id: datastore_db_private.h,v 1.16 2005/04/29 11:44:42 relson Exp $ */
 
 /*****************************************************************************
 
@@ -46,14 +46,6 @@ typedef struct {
 
 #define DBT_init(dbt)		(memset(&dbt, 0, sizeof(DBT)))
 
-typedef	enum {
-    P_ERROR = -1,	/* -1 for error */
-    P_DISABLE = 0,	/*  0 for no transactions - 0 must mean P_DISABLE
-			    for compatibility with dummy functions */
-    P_ENABLE  = 1,	/*  1 for transactions */
-    P_DONT_KNOW		/*  2 for don't know */
-} probe_txn_t;
-
-probe_txn_t probe_txn(bfpath *bfp);
+e_txn probe_txn(bfpath *bfp);
 
 #endif
