@@ -1,4 +1,4 @@
-/* $Id: iconvert.h,v 1.1 2005/01/09 17:32:34 relson Exp $ */
+/* $Id: iconvert.h,v 1.3 2005/06/25 23:23:35 relson Exp $ */
 
 /*****************************************************************************
 
@@ -13,8 +13,9 @@ AUTHOR:
 #ifndef ICONVERT_H
 #define ICONVERT_H
 
-#include "buff.h"
+#include <iconv.h>
 
 extern void iconvert(buff_t *src, buff_t *dst);
+extern void iconvert_cd(iconv_t cd, buff_t *src, buff_t *dst);
 
 #endif
