@@ -1,4 +1,4 @@
-/* $Id: lexer.c,v 1.137 2005/06/28 21:52:31 relson Exp $ */
+/* $Id: lexer.c,v 1.147 2005/12/31 17:17:12 relson Exp $ */
 
 /**
  * \file lexer.c
@@ -90,6 +90,11 @@ static bool long_token(byte *buf, uint count)
     uint i;
     for (i=0; i < count; i += 1) {
 	byte c = buf[i];
+	/* 10/23/05 - fix SIGSEGV with msg.1023.6479.txt
+	** evidently caused by 09/07/05 patch for 0.96.2
+	*/
+	if (c == '\0')
+	    break;
 	if ((iscntrl(c) || isspace(c) || ispunct(c)) && (c != '_'))
 	    return false;
     }
@@ -135,7 +140,7 @@ static int yy_get_new_line(buff_t *buff)
     while (msg_header
 	   && count != EOF
 /* don't skip if inside message/rfc822 */
-	   && msg_state == msg_state->parent
+	   && msg_state->parent == NULL
 	   && memcmp(buff->t.text,spam_header_name,hdrlen) == 0) {
 	count = skip_folded_line(buff);
     }
@@ -146,53 +151,34 @@ static int yy_get_new_line(buff_t *buff)
 static int get_decoded_line(buff_t *buff)
 {
     int count;
-    static buff_t *temp = NULL;
+    buff_t *linebuff;
 
-    uint used = buff->t.leng;
-    byte *buf = buff->t.text + used;
-
-    if (encoding == E_RAW) {
-	temp = buff;
+    if (encoding == E_RAW ||
+	msg_state->mime_dont_decode ) {
+	linebuff = buff;
     }
 #ifndef	DISABLE_UNICODE
     else {
-	if (temp == NULL)
-	    temp = (buff_t *) calloc(sizeof(buff_t), 1);
+	static buff_t *tempbuff = NULL;
+
+	if (tempbuff == NULL)
+	    tempbuff = (buff_t *) calloc(sizeof(buff_t), 1);
 
 	/* UTF-8 uses up to six octets per character.  Make input buffer
 	 * sufficiently small that the UTF-8 text can fit in the output
 	 * buffer */
-	if (temp->size < buff->size / 6) {
-	    xfree(temp->t.text);
-	    temp->size = buff->size / 6;
-	    temp->t.text = (byte *) xmalloc(temp->size+D);
+	if (tempbuff->size < buff->size / 6) {
+	    xfree(tempbuff->t.text);
+	    tempbuff->size = buff->size / 6;
+	    tempbuff->t.text = (byte *) xmalloc(tempbuff->size+D);
 	}
 
-	temp->t.leng = temp->read = 0;
+	tempbuff->t.leng = tempbuff->read = 0;
+	linebuff = tempbuff;
     }
 #endif
 
-    count = yy_get_new_line(temp);
-
-    /* Save the text on a linked list of lines.
-     * Note that we store fixed-length blocks here, not lines.
-     * One very long physical line could break up into more
-     * than one of these. */
-
-    if (passthrough && passmode == PASS_MEM && count > 0)
-	textblock_add(temp->t.text+temp->read, (size_t) count);
-
-#ifndef	DISABLE_UNICODE
-    if (encoding == E_UNICODE) {
-	iconvert(temp, buff);
-	/*
-	 * iconvert, treating multi-byte sequences, can shrink or enlarge
-	 * the output compared to its input.  Correct count.
-	 */
-	if (count > 0)
-	    count = buff->t.leng;
-    }
-#endif
+    count = yy_get_new_line(linebuff);
 
     if (count == EOF) {
 	if ( !ferror(fpin))
@@ -203,6 +189,48 @@ static int get_decoded_line(buff_t *buff)
 	}
     }
 
+    /* Save the text on a linked list of lines.
+     * Note that we store fixed-length blocks here, not lines.
+     * One very long physical line could break up into more
+     * than one of these. */
+
+    if (passthrough && passmode == PASS_MEM && count > 0)
+	textblock_add(linebuff->t.text+linebuff->read, (size_t) count);
+
+    if ( !msg_header && 
+	 !msg_state->mime_dont_decode &&
+	 msg_state->mime_type != MIME_TYPE_UNKNOWN)
+    {
+	word_t temp;
+	uint decoded_count;
+
+	temp.leng = (uint) count;
+	temp.text = linebuff->t.text+linebuff->read;
+
+	decoded_count = mime_decode(&temp);
+	/*change buffer size only if the decoding worked */
+	if (decoded_count != 0 && decoded_count < (uint) count) {
+	    linebuff->t.leng -= (uint) (count - decoded_count);
+	    count = (int) decoded_count;
+	    if (DEBUG_LEXER(1))
+		lexer_display_buffer(linebuff);
+	}
+    }
+
+#ifndef	DISABLE_UNICODE
+    if (encoding == E_UNICODE &&
+	!msg_state->mime_dont_decode)
+    {
+	iconvert(linebuff, buff);
+	/*
+	 * iconvert, treating multi-byte sequences, can shrink or enlarge
+	 * the output compared to its input.  Correct count.
+	 */
+	if (count > 0)
+	    count = buff->t.leng;
+    }
+#endif
+
 #ifdef EXCESSIVE_DEBUG
     /* debug */
     fprintf(dbgout, "%d: ", count);
@@ -210,28 +238,13 @@ static int get_decoded_line(buff_t *buff)
     fprintf(dbgout, "\n");
 #endif
 
-    if ( !msg_header && msg_state->mime_type != MIME_TYPE_UNKNOWN)
-    {
-	word_t line;
-	uint decoded_count;
-
-	line.leng = (uint) (buff->t.leng - used);
-	line.text = buff->t.text + used;
-
-	decoded_count = mime_decode(&line);
-	/*change buffer size only if the decoding worked */
-	if (decoded_count != 0 && decoded_count < (uint) count) {
-	    buff->t.leng -= (uint) (count - decoded_count);
-	    count = (int) decoded_count;
-	    if (DEBUG_LEXER(1))
-		lexer_display_buffer(buff);
-	}
-    }
-
     /* CRLF -> NL */
-    if (count >= 2 && memcmp(buf + count - 2, CRLF, 2) == 0) {
-	count --;
-	*(buf + count - 1) = (byte) '\n';
+    if (count >= 2) {
+	byte *buf = buff->t.text;
+	if (memcmp(buf + count - 2, CRLF, 2) == 0) {
+	    count --;
+	    *(buf + count - 1) = (byte) '\n';
+	}
     }
 
     if (buff->t.leng < buff->size)     /* for easier debugging - removable */
@@ -242,15 +255,15 @@ static int get_decoded_line(buff_t *buff)
 
 static int skip_folded_line(buff_t *buff)
 {
-    for(;;) {
+    for (;;) {
 	int count;
 	buff->t.leng = 0;
 	count = reader_getline(buff);
 	yylineno += 1;
 	/* only check for LWSP-char (RFC-822) aka. WSP (RFC-2822),
 	 * these only include SP and HTAB */
-	if (buff->t.text[0] != ' '
-		&& buff->t.text[0] != '\t')
+	if (buff->t.text[0] != ' ' &&
+	    buff->t.text[0] != '\t')
 	    return count;
 	/* Check for empty line which terminates message header */
 	if (is_eol((char *)buff->t.text, count))
@@ -329,9 +342,8 @@ int yyinput(byte *buf, size_t used, size_t size)
     }
 
     if (msg_state &&
-	msg_state->mime_disposition &&
-	(msg_state->mime_type == MIME_APPLICATION ||  
-	 msg_state->mime_type == MIME_IMAGE)) {
+	msg_state->mime_dont_decode &&
+	(msg_state->mime_disposition != MIME_DISPOSITION_UNKNOWN)) {
 	return (count == EOF ? 0 : count);   /* not decode at all */
     }
 
