@@ -1,4 +1,4 @@
-/* $Id: paths.c,v 1.33 2005/04/04 11:16:22 relson Exp $ */
+/* $Id: paths.c,v 1.51 2005/08/14 13:08:35 relson Exp $ */
 
 /**
  * \file
@@ -40,29 +40,44 @@ static map_pri_env pri_2_env[] = {
 
 char *bogohome = NULL;
 
-bfpath_mode mode;
-
 void set_bogohome(const char *path)
 {
-    if (path) {
-	xfree(bogohome);
-	bogohome = xstrdup(path);
-    }
-    return;
+    xfree(bogohome);
+    bogohome = xstrdup(path);
 }
 
-void bfpath_cleanup(void)
+void chk_bogohome(void)
+{
+    if (!check_directory(bogohome)) {
+	(void)fprintf(stderr, "%s: cannot find bogofilter directory.\n"
+		      "You must specify a directory on the command line, in the config file,\n"
+#ifndef __riscos__
+		      "or by using the BOGOFILTER_DIR or HOME environment variables.\n"
+#else
+		      "or by ensuring that <Bogofilter$Dir> is set correctly.\n"
+#endif
+		      "Program aborting.\n", progname);
+	exit(EX_ERROR);
+    }
+}
+
+static bool cant_find_bogohome(void)
+{
+    if (bogohome != NULL)
+	return false;
+
+    if (set_wordlist_dir(NULL, PR_ENV_BOGO) == 0)
+	return false;
+    if (set_wordlist_dir(NULL, PR_ENV_HOME) == 0)
+	return false;
+
+    return true;
+}
+
+void bogohome_cleanup(void)
 {
     xfree(bogohome);
     bogohome = NULL;
-    return;
-}
-
-void bfpath_set_bogohome_using_priority(priority_t p)
-{
-    const char *h = get_directory(p);
-    set_bogohome(h);
-    return;
 }
 
 int set_wordlist_dir(const char* d, priority_t precedence)
@@ -86,19 +101,8 @@ int set_wordlist_dir(const char* d, priority_t precedence)
 
     saved_precedence = precedence;
 
-    if (!check_directory(dir)) {
-	(void)fprintf(stderr, "%s: cannot find bogofilter directory.\n"
-		      "You must specify a directory on the command line, in the config file,\n"
-#ifndef __riscos__
-		      "or by using the BOGOFILTER_DIR or HOME environment variables.\n"
-#else
-		      "or by ensuring that <Bogofilter$Dir> is set correctly.\n"
-#endif
-		      "Program aborting.\n", progname);
-	rc = -1;
-    }
-
     set_bogohome(dir);
+
     xfree(dir);
 
     return rc;
@@ -120,24 +124,77 @@ char *get_directory(priority_t which)
     return dir;
 }
 
+static bfpath *bfpath_split(bfpath *bfp, const char *home)
+{
+    /* precondition:  bfp->dirname and bfp->filename free'd if need be */
+    char *t = strrchr(bfp->filepath, DIRSEP_C);
+
+    xfree(bfp->dirname);
+    xfree(bfp->filename);
+
+    if (t != NULL) {
+	/* if directory separator present .... */
+	*t = '\0';
+	bfp->dirname = xstrdup(bfp->filepath);
+	*t = DIRSEP_C;
+	bfp->filename = xstrdup(t+1);
+    }
+    else if (home != NULL){
+	bfp->dirname = xstrdup(home);
+	bfp->filename = bfp->filepath;
+	bfp->filepath = mxcat(bfp->dirname, DIRSEP_S, bfp->filename, NULL);
+    }
+    else {
+	bfp->dirname = NULL;
+	bfp->filename = xstrdup(bfp->filepath);
+    }
+
+    return bfp;
+}
+
 bfpath *bfpath_create(const char *path)
 {
     bfpath *bfp = xcalloc(1, sizeof(bfpath));
     bfp->filepath = xstrdup(path);
+
     return bfp;
 }
 
+static void check_for_file(bfpath *bfp)
+{
+    int rc;
+    struct stat sb;
+
+    bfp->isdir = bfp->isfile = false;
+
+    rc = stat(bfp->filepath, &sb);
+    if (rc == 0) {
+	bfp->exists = true;
+	xfree(bfp->dirname);
+	xfree(bfp->filename);
+	if (S_ISDIR(sb.st_mode)) {
+	    bfp->isdir = true;
+	    bfp->dirname  = xstrdup(bfp->filepath);
+	    bfp->filename = NULL;
+	}
+	if (!S_ISDIR(sb.st_mode)) {
+	    bfp->isfile = true;
+	    bfp->dirname  = get_directory_from_path(bfp->filepath);
+	    bfp->filename = get_file_from_path(bfp->filepath);
+	}
+    }
+    return;
+}
+
 bool bfpath_check_mode(bfpath *bfp, bfpath_mode m)
 {
-    int rc;
     bool ok = true;
-    struct stat sb;
 
     bfp->checked = true;
 
     if (bfp->filepath != NULL && bfp->dirname == NULL && bfp->filename == NULL) {
 	char *t = strrchr(bfp->filepath, DIRSEP_C);
-	if (t == NULL) 
+	if (t == NULL)
 	    bfp->filename = xstrdup(bfp->filepath);
 	else {
 	    bfp->dirname = xstrdup(bfp->filepath);
@@ -146,19 +203,7 @@ bool bfpath_check_mode(bfpath *bfp, bfpath_mode m)
 	}
     }
 
-    rc = stat(bfp->filepath, &sb);
-    if (rc == 0) {
-	bfp->exists = true;
-	if (S_ISDIR(sb.st_mode)) {
-	    bfp->isdir = true;
-	    bfp->dirname = xstrdup(bfp->filepath);
-	}
-	if (!S_ISDIR(sb.st_mode)) {
-	    bfp->isfile = true;
-	    bfp->filename = get_file_from_path(bfp->filepath);
-	    bfp->dirname = get_directory_from_path(bfp->filepath);
-	}
-    }
+    check_for_file(bfp);
 
     switch (m)
     {
@@ -173,37 +218,31 @@ bool bfpath_check_mode(bfpath *bfp, bfpath_mode m)
 	abort();
     }
 
-    if (bfp->dirname != NULL)
+    if (bfp->dirname != NULL && bogohome == NULL)
 	set_bogohome(bfp->dirname);
 
     return ok;
 }
 
-void bfpath_set_mode(bfpath_mode m)
+void bfpath_set_bogohome(bfpath *bfp)
 {
-    mode = m;
+    /* ensure bogohome is set */
+    if (cant_find_bogohome()) {
+	fprintf(stderr, "Can't find HOME or BOGOFILTER_DIR in environment.\n");
+	exit(EX_ERROR);
+    }
+
+    bfpath_split(bfp, bogohome);
 }
 
-void bfpath_update(bfpath *bfp)
+void bfpath_set_filename(bfpath *bfp, const char *filename)
 {
-    char *t = strrchr(bfp->filepath, DIRSEP_C);
-
-    xfree(bfp->dirname);
     xfree(bfp->filename);
-
-    if (t != NULL) {
-	/* if directory separator present .... */
-	*t = '\0';
-	bfp->dirname = xstrdup(bfp->filepath);
-	*t = DIRSEP_C;
-	bfp->filename = xstrdup(t+1);
-    }
-    else {
-	/* if directory separator not present, use bogohome */
-	bfp->dirname = xstrdup(bogohome);
-	bfp->filename = bfp->filepath;
-	bfp->filepath = mxcat(bfp->dirname, DIRSEP_S, bfp->filename, NULL);
-    }
+    bfp->filename = xstrdup(filename);
+    xfree(bfp->filepath);
+    bfp->filepath = mxcat(bfp->dirname, DIRSEP_S, bfp->filename, NULL);
+    check_for_file(bfp);
+    return;
 }
 
 bfpath *bfpath_free(bfpath *bfp)
@@ -215,7 +254,7 @@ bfpath *bfpath_free(bfpath *bfp)
     return NULL;
 }
 
-char *build_progtype(const char *name, const char *db_type) 
+char *build_progtype(const char *name, const char *db_type)
 {
     char *type;
     if (strcmp(db_type, "db") == 0)
@@ -285,24 +324,6 @@ bool check_directory(const char* path) /*@globals errno,stderr@*/
     return true;
 }
 
-#if	0
-bool is_file(const char* path) /*@globals errno,stderr@*/
-{
-    bool ok;
-
-    if (path == NULL || *path == '\0')
-	ok = false;
-    else {
-	struct stat sb;
-	int rc = stat(path, &sb);
-
-	ok = (rc == 0) && !S_ISDIR(sb.st_mode);
-    }
-
-    return ok;
-}
-#endif
-
 /** returns malloc()ed copy of the file name part of \a path.
  */
 char *get_file_from_path(const char *path)
