@@ -1,4 +1,4 @@
-/* $Id: score.c,v 1.56 2005/09/04 14:49:43 relson Exp $ */
+/* $Id: score.c,v 1.57 2006/01/30 22:35:55 relson Exp $ */
 
 /*****************************************************************************
 
@@ -408,18 +408,18 @@ double get_spamicity(size_t robn, FLOAT P, FLOAT Q)
     return score.spamicity;
 }
 
-void msg_print_summary(void)
+void msg_print_summary(const char *pfx)
 {
     if (!Rtable) {
-	(void)fprintf(fpo, "%-*s %6lu %9.6f %9.6f %9.6f\n",
-		      MAXTOKENLEN+2, "N_P_Q_S_s_x_md", (unsigned long)score.robn, 
+	(void)fprintf(fpo, "%s%-*s %6lu %9.6f %9.6f %9.6f\n",
+		      pfx, MAXTOKENLEN+2, "N_P_Q_S_s_x_md", (unsigned long)score.robn, 
 		      score.p_pr, score.q_pr, score.spamicity);
-	(void)fprintf(fpo, "%-*s  %9.6f %9.6f %9.6f\n",
-		      MAXTOKENLEN+2+6, " ", robs, robx, min_dev);
+	(void)fprintf(fpo, "%s%-*s  %9.6f %9.6f %9.6f\n",
+		      pfx, MAXTOKENLEN+2+6, " ", robs, robx, min_dev);
     }
     else
-	(void)fprintf(fpo, "%-*s %6lu %9.2e %9.2e %9.2e %9.2e %9.2e %5.3f\n",
-		      MAXTOKENLEN+2, "N_P_Q_S_s_x_md", (unsigned long)score.robn, 
+	(void)fprintf(fpo, "%s%-*s %6lu %9.2e %9.2e %9.2e %9.2e %9.2e %5.3f\n",
+		      pfx, MAXTOKENLEN+2, "N_P_Q_S_s_x_md", (unsigned long)score.robn, 
 		      score.p_pr, score.q_pr, score.spamicity, robs, robx, min_dev);
 }
 
