@@ -1,4 +1,4 @@
-/* $Id: score.h,v 1.5 2004/07/08 12:20:32 relson Exp $ */
+/* $Id: score.h,v 1.7 2006/01/30 22:35:55 relson Exp $ */
 /*  constants and declarations for robinson-fisher method */
 
 #ifndef	FISHER_H
@@ -22,6 +22,7 @@ typedef struct score_s {
     double q_pr;	/* Robinson Q */
 } score_t;
 
+extern	void	lookup_words(wordhash_t *wh);
 extern	void	score_initialize(void);
 extern	void	score_cleanup(void);
 
@@ -29,7 +30,7 @@ extern	double	msg_compute_spamicity(wordhash_t *wordhash, FILE *fp) /*@globals e
 extern	double	msg_spamicity(void);
 extern	rc_t	msg_status(void);
 extern	void	msg_print_stats(FILE *fp);
-extern	void	msg_print_summary(void);
+extern	void	msg_print_summary(const char *pfx);
 
 extern	 void	print_summary(void);
 
